#ifndef CONTACTSTHREADWORKER_H
#define CONTACTSTHREADWORKER_H

#include <QtCore>
#include <QContact>
#include <QContactId>

class k9call;

class ContactsThreadWorker : public QThread
{
    Q_OBJECT

public:
    ContactsThreadWorker(k9call* k);
    void run();

signals:
    void updateContacts(QList<QtMobility::QContact>);
    void updateContactIds (QList< QtMobility::QContactLocalId >);

public slots:
    void syncContacts();
    void syncContactIds();
};

#endif // CONTACTSTHREADWORKER_H
